<?xml version="1.0" ?><!DOCTYPE TS><TS language="ro" version="2.1">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Există viață dincolo de browser!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Versiunea %1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Licențiat la %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 este un program gratuit, dar dezvoltarea acestuia necesită timp prețios.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Te rog &lt;a href=&apos;%1&apos;&gt;donează&lt;/a&gt; pentru a sprijini dezvoltarea în continuare a %2.</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Tradu %1 în limba proprie folosind %2</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open-source software</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Iconița a fost concepută de %1.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Oferit sub &lt;a href=&apos;%1&apos;&gt;Licența Publică Generală GNU&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>În&amp;chide</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Despre</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Introdu detaliile licenței tale</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;Email:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Cod:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Licențiați %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Această versiune demo a expirat.</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation>Versiunea nerestricționată vă permite să urmăriți clipurile video fără întreruperi.</translation>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>Fără licență, aplicația va expira în %1 zile.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Cumpărând versiunea integrală îmi sprijini efortul depus pentru crearea %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Folosește Demo</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Introdu Licența</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Cumpără Licență</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation>Descarcă</translation>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation>De %1</translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation>Toate videoclipurile</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Videoclipuri pe care nu le-ai vazut</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>Nume</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation>Ultimele actualizări</translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation>Ultimele adaugate</translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation>Ultimele vazute</translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation>Cele mai vazute</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Sortează după</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation>Marcheaza tot ca vazut</translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation>Arata actualizeazările</translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>Nu esti abonat la nimic. Ca sa te abonezi la canale, foloseste simbolul stea.</translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation>Toate videoclipurile</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Videoclipuri pe care nu le-ai vazut</translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation>Marcat ca vizualizat</translation>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation>Dezabonează</translation>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation>Nici unul din canalele la care esti abonat nu are actualizari momentan.</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation>Doar acum</translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 views</source>
        <translation>%1 vizionări</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>bytes/sec</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>KB/sec</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>MB/sec</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>secunde</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minute</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 rămase</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>%1 descărcat în %2</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Descărcare terminată</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Schimbă locația...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>Alege locația de descărcare</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>Locația de descărcare a fost schimbată.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Fişierele în curs de descărcare vor fi salvate în locația anterioară.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>Descărcare în: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>Descărcări</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation>Fișierul executabil a fost infestat cu un virus.</translation>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation>%1 nu va rula. Încercați să-l instalați din nou.</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Termină</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>Reinstalare</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Redare</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauză</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Redare/Pauză</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Opreşte redarea după piesa curentă</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Piesa următoare</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Piesa anterioară</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Creștere volumul</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Descreștere volumul</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Mut</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Caută înainte</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Caută înapoi</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>Caută</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>Videoclipuri complete şi canale după cuvinte cheie</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Rasfoieste</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>Uita-te la videoclipuri pe categori</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Abonamente</translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation>Canale la care esti abonat</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Fa-te confortabil</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Eroare</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Fereastră</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Minimizează</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Stop</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Oprește redarea și întoarce-te la căsuța de căutare</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>&amp;Anterioare</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Mergi înapoi la piesa precedentă</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>O&amp;mite</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Treci la videoclipul următor</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Redare</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Rezumă redarea videoclipului</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>Ec&amp;ran complet</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Vizualizează pe tot ecranul</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>Modul &amp;Compact</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Ascunde lista de redare și bara de unelte</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>Deschide Pagina &amp;YouTube</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Deschide pagina de pe YouTube si pune pauză</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>Copiază &amp;adresa videoclipului YouTube</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Copiază adresa videoclipului YouTube curent în clipboard</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>Copiază adresa &amp;fluxului video</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Copiază adresa fluxului video curent în clipboard</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>Caută &amp;Părți ale Videoclipului</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>Caută alte părți ale videoclipului</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>Ș&amp;terge</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Șterge videoclipul selectat din lista de redare</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Mută în &amp;sus</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Mută în sus videoclipul selectat</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Mută în &amp;jos</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Mută în jos videoclipul selectat</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>Șt&amp;erge Căutările Recente</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Curăță istoricul de căutări. Acțiune ireversibilă.</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Ieșire</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>La revedere</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>Site &amp;Web</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 pe Web</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>Fă o &amp;Donație</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Te rog să susții dezvoltarea aplicației %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Despre</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Informații despre %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Căutare</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Oprire sunet</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>Pornește Redarea &amp;Manual</translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>Pornește redarea videoclipurilor manual</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>&amp;Descărcări</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>Arată detalii despre descărcările video</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;Descărcare</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Descarcă videoclipul curent</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation>Fă &amp;captură de ecran</translation>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation>&amp;Aboneza-te la canal</translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>Împărtășește videoclipul curent folosind %1</translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>&amp;Email</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Email</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>În&amp;chide</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>&amp;Detașează</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>&amp;Oprește După Acest Videoclip</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;Raportează o problemă...</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>&amp;Căutare rafinată...</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>Mai multe...</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>&amp;Videoclipuri asemanatoare</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>Uita-te la videoclipuri similare cu cel curent</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation>Deschide in &amp;Navigatorul web...</translation>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation>Mod restricționat</translation>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation>Ascundeți videoclipuri care pot conține conținut neadecvat</translation>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>&amp;Vă place %1? Evaluați-l!</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Cumpără %1...</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Aplicație</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Redare</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Listă de redare</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>Î&amp;mpărtășește</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>Vi&amp;zualizare</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ajutor</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Apasă pe %1 pentru a da volumul mai tare sau pe %2 pentru a-l da mai încet</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>Alege localizarea continutului</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Deschidere %1</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Doriţi să ieșiți din %1 cu o descărcare în progres?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Dacă ieșiți acum din %1, procesul de descărcare va fi anulat.</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Închide și anulează descărcarea</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>Așteaptă ca descărcarea să se încheie</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Eroare: %1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pauză</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Pune redarea pe pauză</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation>&amp;Se încarcă...</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Ieși din Ec&amp;ran Complet</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Timp rămas : %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Volum %1</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Sunetul este oprit</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Sunetul este pornit</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Rezoluția maxima a videoclipului este setată la %1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Intimitatea dumneavoastră este acum în siguranță</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>Descărcări complete</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>Versiunea %1 a %2 este acum disponibilă.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Reamintește-mi mai târziu</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Actualizează</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Acum poți adăuga adresa YouTube într-o altă aplicație</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Acum poți adăuga adresa fluxului video într-o altă aplicație</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>Adresa va fi validă doar pentru o perioadă limitată de timp.</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Descărcare %1</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>din</translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>partea</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>episodul</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>Trimis din %1</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation>Dezaboneaza-te de la %1</translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation>Aboneaza-te de la %1</translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation>Dezabonează-te de la %1</translation>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation>Abonează-te la %1</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>O nouă versiune %1 este disponibilă!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 este acum disponibilă. Tu ai %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Dorești descărcarea ei acum?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Renunță la Această Versiune</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Amintește-mi Mai Târziu</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Instalează Actualizări</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Adaugă</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 din %2 (%3) — %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Se pregateste</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Eșec</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Terminat</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Oprit</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>Oprește descărcarea</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>Arată în %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>Deschide directorul părinte</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>Reporneste descărcarea</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>Afișează încă %1</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Nici un videoclip</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Nu mai sunt videoclipuri</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>Sortează după</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>Relevanță</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dată</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>Vizualizări</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>Evaluare</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>Oricând</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Astăzi</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>7 Zile</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>30 Zile</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Durată</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Toate</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>Scurt</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Mediu</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>Lung</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>Mai scurt de 4 minute</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>Între 4 și 20 minute</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>Mai lung de 20 minute</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Calitate</translation>
    </message>
    <message>
        <source>High Definition</source>
        <translation>Înaltă Definiție HD</translation>
    </message>
    <message>
        <source>720p or higher</source>
        <translation>720p sau definiție mai mare</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Terminat</translation>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>Terminat</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Caută</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Bine ați venit la &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>pentru a începe să vizionați videoclipuri.</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>un cuvânt cheie</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Introduceți</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Căutări recente</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>Canale recente</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Obține versiunea integrală</translation>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>Î&amp;napoi</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>Avanseaza la %1</translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>Inapoi la %1</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>Căutare Rafinată</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>Ai vrut să spui: %1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Schimbă locația...</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation>Captură de ecran salvată la %1</translation>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation>Locația instantaneelor a fost modificată.</translation>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>Cel mai popular</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>Descărcare actualizări...</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation>Se descarcă %1</translation>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>Algeria</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>Argentina</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>Australia</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>Belgia</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>Brazilia</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>Canada</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>Chile</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>Columbia</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>Cehia</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>Egipt</translation>
    </message>
    <message>
        <source>France</source>
        <translation>Franta</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>Germania</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>Ghana</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>Grecia</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>Hong Kong</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>Ungaria</translation>
    </message>
    <message>
        <source>India</source>
        <translation>India</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Indonesia</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>Irlanda</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>Israel</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>Italia</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>Japonia</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>Iordania</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>Kenya</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>Malaezia</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>Mexic</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>Maroc</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>Olanda</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>Noua Zeelanda</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>Nigeria</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>Peru</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>Filipine</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>Polonia</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>Rusia</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>Arabia Saudita</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>Singapore</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>Africa de Sud</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>Coreea de Sud</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>Spania</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>Suedia</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>Taiwan</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>Tunisia</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>Turcia</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>Uganda</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>Emiratele Arabe Unite</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>Marea Britanie</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>Yemen</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>Global</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>Nu poate fi accesat fluxul video pentru %1</translation>
    </message>
</context>
</TS>